pyrestsdk.request.supports_types package — PyRESTSDK documentation

# pyrestsdk.request.supports_types package

## Subpackages

- pyrestsdk.request.supports_types.methods package
  - Module contents

## Module contents

Supports Types

class pyrestsdk.request.supports_types.SupportsBaseInvokeRequest(*args, **kwargs)

  Bases: `Protocol`

  Supports Base Invoke Request Type

  abstract Send() → List[T] | T | None
  abstract property generic_type: Type[T]
  abstract property input_object: T
  abstract invoke_request() → List[T] | T | None

    Invokes the prepared request

class pyrestsdk.request.supports_types.SupportsDeleteMethod(*args, **kwargs)

  Bases: `SupportsMethods`

  Supports Delete Method Type

  property Delete: Self

    Sets request to delete request

class pyrestsdk.request.supports_types.SupportsGetMethod(*args, **kwargs)

  Bases: `SupportsMethods`

  Supports Get Method Type

  property Get: Self

    Sets request to get request

class pyrestsdk.request.supports_types.SupportsHeaderOptions(*args, **kwargs)

  Bases: `Protocol`

  Supports Header Options Type

  property header_options: HeaderOptionCollection

    Gets Header Options

class pyrestsdk.request.supports_types.SupportsInvokeCollectionRequest(*args, **kwargs)

  Bases: `SupportsBaseInvokeRequest`

  property invoke_request: List[T]

    Invokes the prepared request

class pyrestsdk.request.supports_types.SupportsInvokeRequest(*args, **kwargs)

  Bases: `SupportsBaseInvokeRequest`

  property invoke_request: T

    Invokes the prepared request

class pyrestsdk.request.supports_types.SupportsPostMethod(*args, **kwargs)

  Bases: `SupportsMethods`

  Supports Post Method Type

  Post(input_object: S) → Self

    Sets request to put request

class pyrestsdk.request.supports_types.SupportsPutMethod(*args, **kwargs)

  Bases: `SupportsMethods`

  Supports Put Method Type

  Put(input_object: S) → Self

    Sets request to put request

class pyrestsdk.request.supports_types.SupportsQueryOptions(*args, **kwargs)

  Bases: `Protocol`

  Supports Query Options Type

  property query_options: QueryOptionCollection

    Gets Query Options